==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/id/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'Lisensi tidak ada.',
    'user_does_not_exist' => 'Pengguna tidak ada.',
    'asset_does_not_exist' 	=> 'Aset yang hendak di asosiasikan dengan lisensi ini tidak ada.',
    'owner_doesnt_match_asset' => 'Aset yang hendak di asosiasikan dengan lisensi ini di miliki oleh seseorang yang tidak masuk dalam daftar.',
    'assoc_users'	 => 'Lisensi ini sudah diberikan kepada pengguna dan tidak dapat di hapus. Silahkan cek lisensi terlebih dahulu kemudian coba hapus kembali. ',
    'select_asset_or_person' => 'Anda harus memilih aset atau pengguna, namun tidak keduanya.',
    'not_found' => 'License not found',


    'create' => array(
        'error'   => 'Gagal membuat lisensi, silahkan coba kembali.',
        'success' => 'Sukses membuat lisensi.'
    ),

    'deletefile' => array(
        'error'   => 'Berkas belum terhapus. Silahkan coba kembali.',
        'success' => 'Berkas sukses di hapus.',
    ),

    'upload' => array(
        'error'   => 'Berkas belum terunggah. Silakan coba kembali.',
        'success' => 'Berkas sukses terunggah.',
        'nofiles' => 'Anda belum memilih berkas untuk di unggah, atau berkas yang akan di unggah terlalu besar ukurannya',
        'invalidfiles' => 'Satu atau lebih file Anda terlalu besar atau merupakan jenis filetype yang tidak diizinkan. Filetype yang diperbolehkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml, dan lic.',
    ),

    'update' => array(
        'error'   => 'Gagal memperbarui lisensi, silahkan coba kembali',
        'success' => 'Sukses perbarui lisensi.'
    ),

    'delete' => array(
        'confirm'   => 'Apakah Anda yakin untuk menghapus lisensi ini?',
        'error'   => 'Terdapat kesalahan pada saat penghapusan lisensi ini. Silahkan coba kembali.',
        'success' => 'Lisensi telah berhasil dihapus.'
    ),

    'checkout' => array(
        'error'   => 'Terdapat kesalahan pada saat pemberian lisensi ini. Silahkan coba kembali.',
        'success' => 'Lisensi telah berhasil diberikan'
    ),

    'checkin' => array(
        'error'   => 'Terdapat kesalahan pada saat penerimaan lisensi ini. Silahkan coba kembali.',
        'success' => 'Lisensi telah berhasil diterima'
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/id/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'Lisensi tidak ada.',
    'user_does_not_exist' => 'Pengguna tidak ada.',
    'asset_does_not_exist' 	=> 'Aset yang hendak di asosiasikan dengan lisensi ini tidak ada.',
    'owner_doesnt_match_asset' => 'Aset yang hendak di asosiasikan dengan lisensi ini di miliki oleh seseorang yang tidak masuk dalam daftar.',
    'assoc_users'	 => 'Lisensi ini sudah diberikan kepada pengguna dan tidak dapat di hapus. Silahkan cek lisensi terlebih dahulu kemudian coba hapus kembali. ',
    'select_asset_or_person' => 'Anda harus memilih aset atau pengguna, namun tidak keduanya.',
    'not_found' => 'Berkas Lisensi tidak ditemukan',


    'create' => array(
        'error'   => 'Gagal membuat lisensi, silahkan coba kembali.',
        'success' => 'Sukses membuat lisensi.'
    ),

    'deletefile' => array(
        'error'   => 'Berkas belum terhapus. Silahkan coba kembali.',
        'success' => 'Berkas sukses di hapus.',
    ),

    'upload' => array(
        'error'   => 'Berkas belum terunggah. Silakan coba kembali.',
        'success' => 'Berkas sukses terunggah.',
        'nofiles' => 'Anda belum memilih berkas untuk di unggah, atau berkas yang akan di unggah terlalu besar ukurannya',
        'invalidfiles' => 'Satu atau lebih file Anda terlalu besar atau merupakan jenis filetype yang tidak diizinkan. Filetype yang diperbolehkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml, dan lic.',
    ),

    'update' => array(
        'error'   => 'Gagal memperbarui lisensi, silahkan coba kembali',
        'success' => 'Sukses perbarui lisensi.'
    ),

    'delete' => array(
        'confirm'   => 'Apakah Anda yakin untuk menghapus lisensi ini?',
        'error'   => 'Terdapat kesalahan pada saat penghapusan lisensi ini. Silahkan coba kembali.',
        'success' => 'Lisensi telah berhasil dihapus.'
    ),

    'checkout' => array(
        'error'   => 'Terdapat kesalahan pada saat pemberian lisensi ini. Silahkan coba kembali.',
        'success' => 'Lisensi telah berhasil diberikan'
    ),

    'checkin' => array(
        'error'   => 'Terdapat kesalahan pada saat penerimaan lisensi ini. Silahkan coba kembali.',
        'success' => 'Lisensi telah berhasil diterima'
    ),

);
